/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.hadoop.metadata;

import java.io.Serializable;
import java.util.Map;
import java.util.Set;

/**
 * Strategy to merge metadata. Possible implementations:
 * 1) Expect metadata to be exactly identical. Otherwise throw error (this is the default strategy implementation)
 * 2) Custom strategy to merge metadata if the values are not identical. Example: concatenate values.
 */
public interface KeyValueMetadataMergeStrategy extends Serializable {
  /**
   * @param keyValueMetaData the merged app specific metadata
   */
  Map<String, String> merge(Map<String, Set<String>> keyValueMetaData);
}
